@@ -13,12 +13,6 @@ from pysmi.codegen.base import AbstractCodeGen, dorepr
 from pysmi import error
 from pysmi import debug
 
-if sys.version_info[0] > 2:
-    # noinspection PyShadowingBuiltins
-    unicode = str
-    # noinspection PyShadowingBuiltins
-    long = int
-
 
 class SymtableCodeGen(AbstractCodeGen):
     symsTable = {
@@ -392,7 +386,7 @@ class SymtableCodeGen(AbstractCodeGen):
     def genDefVal(self, data, classmode=False):  # XXX should be fixed, see pysnmp.py
         defval = data[0]
 
-        if isinstance(defval, (int, long)):  # number
+        if isinstance(defval, int):  # number
             val = str(defval)
 
         elif self.isHex(defval):  # hex
@@ -469,12 +463,12 @@ class SymtableCodeGen(AbstractCodeGen):
     def genOid(self, data, classmode=False):
         out = ()
         for el in data[0]:
-            if isinstance(el, (str, unicode)):
+            if isinstance(el, str):
                 parent = self.transOpers(el)
                 self._parentOids.add(parent)
                 out += ((parent, self._importMap.get(parent, self.moduleName[0])),)
 
-            elif isinstance(el, (int, long)):
+            elif isinstance(el, int):
                 out += (el,)
 
             elif isinstance(el, tuple):
@@ -624,10 +618,10 @@ class SymtableCodeGen(AbstractCodeGen):
         self._out['_symtable_rows'] = list(self._rows)
 
         debug.logger & debug.flagCodegen and debug.logger(
-            'canonical MIB name %s (%s), imported MIB(s) %s, Symbol table size %s symbols' % (
+            'canonical MIB name {} ({}), imported MIB(s) {}, Symbol table size {} symbols'.format(
                 self.moduleName[0], moduleOid, ','.join(importedModules) or '<none>', len(self._out)))
 
         return MibInfo(oid=None,
                        name=self.moduleName[0],
                        revision=self._moduleRevision,
-                       imported=tuple([x for x in importedModules])), self._out
+                       imported=tuple(x for x in importedModules)), self._out
